@@ -2,7 +2,6 @@
 # Copyright 2011-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-
 from dateutil.rrule import rrule
 
 from django.conf import settings
@@ -19,6 +18,8 @@ from django.utils.encoding import force_text
 try:
     from num2words import num2words
 except ImportError:
+    # ignore silently to avoid test failures when it is not installed
+    # print("num2words not installed, use `python manage.py install` to install")
     pass  # run `manage.py install` to install it
 
 from lino import mixins
@@ -458,8 +459,8 @@ class EventGenerator(dd.Model):
 
     def suggest_cal_guests(self, event):
         """Yield or return a list of (unsaved) :class:`Guest
-        <lino_xl.lib.cal.models.Guest>` objects representing the
-        participants to invite to every the given event. Called on
+        <lino_xl.lib.cal.Guest>` objects representing the
+        participants to invite to the given event. Called on
         every event generated by this generator.
 
         """
@@ -497,9 +498,7 @@ class RecurrenceSet(Started, Ended):
 
     #~ every_unit = DurationUnits.field(_("Repeat every (unit)"),
     every_unit = Recurrencies.field(
-        _("Recurrency"),
-        default=Recurrencies.as_callable('monthly'),
-        blank=True)  # iCal:DURATION
+        _("Recurrency"), default='monthly', blank=True)
     every = models.IntegerField(_("Repeat every"), default=1)
     positions = models.CharField(_("Positions"), blank=True, max_length=50)
 
@@ -662,7 +661,7 @@ class RecurrenceSet(Started, Ended):
             return rrule(
                 freq=freq,
                 count=2, dtstart=date+ONE_DAY, interval=self.every,
-                bysetpos=bysetpos, byweekday=weekdays)[0]
+                bysetpos=bysetpos, byweekday=weekdays)[0].date()
 
         if self.every_unit == Recurrencies.per_weekday:
             # per_weekday is deprecated to by replaced by daily.
