@@ -729,11 +729,11 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
     def is_user_modified(self):
         return self.state != EntryStates.suggested
 
-    def before_ui_save(self, ar, **kw):
+    def before_ui_save(self, ar, cw):
         # logger.info("20130528 before_ui_save")
         if self.state is EntryStates.suggested:
             self.state = EntryStates.draft
-        super(Event, self).before_ui_save(ar, **kw)
+        super(Event, self).before_ui_save(ar, cw)
 
     def on_create(self, ar):
         if self.event_type is None:
@@ -777,9 +777,11 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
                 obj.save()
 
     def can_edit_guests_manually(self):
+        # print("20200901", self.state, self.state.fill_guests)
         if self.state.fill_guests:
             if self.event_type and self.event_type.fill_presences:
                 return False
+        # print("20200901 yes")
         return True
 
     def suggest_guests(self):
@@ -791,9 +793,6 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
                 done.add(o)
                 for obj in o.suggest_cal_guests(self):
                     yield obj
-        # if self.owner:
-        #     for obj in self.owner.suggest_cal_guests(self):
-        #         yield obj
 
     summary_project_template = _("for {project}")
     summary_show_user = True
@@ -1075,6 +1074,18 @@ class Guest(Printable):   # TODO: rename the model to "Presence"
             return ''
         return ar.obj2html(self.event, tuple(self.event.get_event_summary(ar)))
 
+    @dd.chooser()
+    def partner_choices(cls):
+        # needed to activate create_partner_choice
+        # returns the same queryset as if there was no chooser
+        t = dd.plugins.cal.partner_model.get_default_table()
+        return t.request().data_iterator
+        # m = dd.plugins.cal.partner_model
+        # return m.objects.order_by(*m.get_default_table().order_by)
+
+    def create_partner_choice(self, text):
+        return dd.plugins.cal.partner_model.create_from_choice(text)
+
 
 def migrate_reminder(obj, reminder_date, reminder_text,
                      delay_value, delay_type, reminder_done):
