@@ -237,8 +237,5 @@ class PanelEvents(Events):
         return obj
 
 
-def setup_quicklinks(site, user, m):
-    m.add_action('extensible.CalendarPanel')
-
 
 # __all__ = ['CalendarPanel']
