@@ -173,7 +173,7 @@ class VatProductInvoice(SalesDocument, Matching):
             partner=self.get_partner(),
             cleared=False,
             match=self.get_match())
-        return Movement.get_balance(not self.journal.dc, qs)
+        return Movement.get_balance(self.journal.dc.opposite(), qs)
 
     @dd.virtualfield(dd.PriceField(_("Balance before")))
     def balance_before(self, ar):
@@ -183,7 +183,7 @@ class VatProductInvoice(SalesDocument, Matching):
             cleared=False,
             value_date__lte=self.entry_date)
         qs = qs.exclude(voucher=self)
-        return Movement.get_balance(not self.journal.dc, qs)
+        return Movement.get_balance(self.journal.dc.opposite(), qs)
 
 
 class InvoiceDetail(dd.DetailLayout):
@@ -226,6 +226,7 @@ class Invoices(SalesDocuments):
     column_names = "id entry_date partner total_incl user *"
     detail_layout = 'sales.InvoiceDetail'
     insert_layout = dd.InsertLayout("""
+    journal
     partner entry_date
     subject
     """, window_size=(40, 'auto'))
@@ -247,11 +248,15 @@ class Invoices(SalesDocuments):
 class InvoicesByJournal(Invoices, ByJournal):
     quick_search_fields = "partner subject"
     order_by = ["-accounting_period__year", "-number"]
+    insert_layout = """
+    partner entry_date
+    subject
+    """
     params_panel_hidden = True
     params_layout = "partner start_period end_period #year state cleared "
-    column_names = "number_with_year entry_date due_date " \
+    column_names = "number_with_year entry_date #due_date " \
         "partner " \
-        "total_incl subject:10 " \
+        "subject:10 total_incl " \
         "workflow_buttons *"
 
 class PrintableInvoicesByJournal(PrintableByJournal, Invoices):
