@@ -923,3 +923,12 @@ class TicketsBySite(Tickets):
         # kw.update(end_date=dd.today())
         # kw.update(observed_event=TicketEvents.todo)
         return kw
+
+
+class CheckListItems(dd.Table):
+    model = "tickets.CheckListItem"
+    column_names = "ticket details checked"
+
+class CheckListItemsByTicket(CheckListItems):
+    master_key = "ticket"
+    column_names = "details checked"
