@@ -14,7 +14,7 @@
 
 SETUP_INFO = dict(
     name='lino-xl',
-    version='20.7.7',
+    version='21.1.0',
     install_requires=['lino'],  # odfpy dependency now in lino_xl.lib.appypod
     tests_require=[],
     description="Lino Extensions Library",
@@ -85,6 +85,8 @@ lino_xl.lib.contacts.management.commands
 lino_xl.lib.countries
 lino_xl.lib.countries.fixtures
 lino_xl.lib.courses
+lino_xl.lib.courses.fixtures
+lino_xl.lib.courses.workflows
 lino_xl.lib.cv
 lino_xl.lib.cv.fixtures
 lino_xl.lib.dupable_partners
